@@ -685,8 +685,10 @@ def SQLAnalyze(p_SQLCommandPlainText):
     for m_nPos in range(0, len(SQLSplitResults)):
         # 去掉行尾的空格
         SQLSplitResults[m_nPos] = SQLSplitResults[m_nPos].rstrip()
-        # 去掉行尾的最后一个分号, “但是如果是END；结尾的，最后的；不能去掉”
-        if SQLSplitResults[m_nPos][-1:] == ';' and not SQLSplitResults[m_nPos].upper().endswith("END;"):
+        # 去掉行尾的最后一个分号, “但是开头是BEGIN或者DECLARE开头的，不去掉
+        if SQLSplitResults[m_nPos][-1:] == ';' and \
+                not SQLSplitResults[m_nPos].upper().startswith("BEGIN") and \
+                not SQLSplitResults[m_nPos].upper().startswith("DECLARE"):
             SQLSplitResults[m_nPos] = SQLSplitResults[m_nPos][:-1]
 
     # 去掉注释信息中的最后一个回车换行符
@@ -741,6 +743,32 @@ def SQLAnalyze(p_SQLCommandPlainText):
                         m_SQLHint["LogMask"].append(m_SQLMask)
                     else:
                         m_SQLHint["LogMask"] = [m_SQLMask]
+
+                # [Hint]  SQL_DIRECT   -- SQLCli执行的时候将不再尝试解析语句，而是直接解析执行
+                matchObj = re.search(r"^(\s+)?--(\s+)?\[Hint](\s+)?SQL_DIRECT", line,
+                                     re.IGNORECASE | re.DOTALL)
+                if matchObj:
+                    m_SQLHint["SQL_DIRECT"] = True
+
+                # [Hint]  SQL_PREPARE   -- SQLCli执行的时候将首先尝试解析语句，随后执行
+                matchObj = re.search(r"^(\s+)?--(\s+)?\[Hint](\s+)?SQL_PREPARE", line,
+                                     re.IGNORECASE | re.DOTALL)
+                if matchObj:
+                    m_SQLHint["SQL_PREPARE"] = True
+
+                # [Hint]  Loop   -- 循环执行特定的SQL
+                # --[Hint] LOOP [LoopTimes] UNTIL [EXPRESSION] INTERVAL [INTERVAL]
+                matchObj = re.search(r"^(\s+)?--(\s+)?\[Hint](\s+)?LOOP\s+(\d+)"
+                                     r"\s+UNTIL\s+(.*)"
+                                     r"\s+INTERVAL\s+(\d+)(\s+)?", line,
+                                     re.IGNORECASE | re.DOTALL)
+                if matchObj:
+                    m_SQLHint["SQL_LOOP"] = {
+                        "LoopTimes": matchObj.group(4),
+                        "LoopUntil": matchObj.group(5),
+                        "LoopInterval": matchObj.group(6)
+                    }
+
             m_SQLHints.append({})     # 对于注释信息，所有的SQLHint信息都是空的
         else:
             # 这里是一个可执行SQL信息
